@@ -2,15 +2,15 @@
 #######################################################################
 """ Any Interface Adapter to IPager Interface
 
-$Id: pageradapter.py 49617 2008-01-21 13:24:50Z cray $
+$Id: pageradapter.py 49627 2008-01-21 15:31:34Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49617 $"
+__version__ = "$Revision: 49627 $"
 
 from zope.interface import implements,Interface
 from zope.component import adapts
-from ng.registry.interfaces import IRegistry
+from ng.app.registry.interfaces import IRegistry
 from zope.app.zapi import getUtility
 from zope.cachedescriptors.property import CachedProperty
 from interfaces import IPager, IPagerSource
